@@ -7,8 +7,8 @@ import (
 	"sync"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func main() {
@@ -23,11 +23,11 @@ func main() {
 	wg.Add(numBars)
 
 	for i := 0; i < numBars; i++ {
-		name := fmt.Sprintf("Bar#%d:", i)
+		name := fmt.Sprintf("Bar#%02d: ", i)
 		bar := p.AddBar(int64(total),
 			mpb.PrependDecorators(
-				decor.Name(name),
-				decor.EwmaETA(decor.ET_STYLE_GO, 60, decor.WCSyncSpace),
+				decor.Name(name, decor.WCSyncWidthR),
+				decor.EwmaETA(decor.ET_STYLE_GO, 30, decor.WCSyncWidth),
 			),
 			mpb.AppendDecorators(
 				// note that OnComplete will not be fired, because of cancel
@@ -39,14 +39,13 @@ func main() {
 			defer wg.Done()
 			rng := rand.New(rand.NewSource(time.Now().UnixNano()))
 			max := 100 * time.Millisecond
-			for !bar.Completed() {
+			for bar.IsRunning() {
 				// start variable is solely for EWMA calculation
 				// EWMA's unit of measure is an iteration's duration
 				start := time.Now()
 				time.Sleep(time.Duration(rng.Intn(10)+1) * max / 10)
-				bar.Increment()
-				// since EWMA based decorator is used, DecoratorEwmaUpdate should be called
-				bar.DecoratorEwmaUpdate(time.Since(start))
+				// we need to call EwmaIncrement to fulfill ewma decorator's contract
+				bar.EwmaIncrement(time.Since(start))
 			}
 		}()
 	}
