@@ -5,8 +5,8 @@ import (
 	"math/rand"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func main() {
@@ -15,7 +15,7 @@ func main() {
 	total := 100
 	bar := p.New(int64(total),
 		mpb.NopStyle(), // make main bar style nop, so there are just decorators
-		mpb.BarExtender(extended(mpb.BarStyle())), // extend wtih normal bar on the next line
+		mpb.BarExtender(extended(mpb.BarStyle().Build()), false), // extend wtih normal bar on the next line
 		mpb.PrependDecorators(
 			decor.Name("Percentage: "),
 			decor.NewPercentage("%d"),
@@ -37,10 +37,13 @@ func main() {
 	p.Wait()
 }
 
-func extended(builder mpb.BarFillerBuilder) mpb.BarFiller {
-	filler := builder.Build()
-	return mpb.BarFillerFunc(func(w io.Writer, reqWidth int, st decor.Statistics) {
-		filler.Fill(w, reqWidth, st)
-		w.Write([]byte("\n"))
+func extended(base mpb.BarFiller) mpb.BarFiller {
+	return mpb.BarFillerFunc(func(w io.Writer, st decor.Statistics) error {
+		err := base.Fill(w, st)
+		if err != nil {
+			return err
+		}
+		_, err = io.WriteString(w, "\n")
+		return err
 	})
 }
