@@ -3,7 +3,6 @@ package main
 import (
 	"crypto/rand"
 	"io"
-	"io/ioutil"
 	"time"
 
 	"github.com/vbauerster/mpb/v8"
@@ -11,8 +10,17 @@ import (
 )
 
 func main() {
-	var total int64 = 1024 * 1024 * 500
-	reader := io.LimitReader(rand.Reader, total)
+	var total int64 = 64 * 1024 * 1024
+
+	r, w := io.Pipe()
+
+	go func() {
+		for i := 0; i < 1024; i++ {
+			_, _ = io.Copy(w, io.LimitReader(rand.Reader, 64*1024))
+			time.Sleep(time.Second / 10)
+		}
+		w.Close()
+	}()
 
 	p := mpb.New(
 		mpb.WithWidth(60),
@@ -32,11 +40,11 @@ func main() {
 	)
 
 	// create proxy reader
-	proxyReader := bar.ProxyReader(reader)
+	proxyReader := bar.ProxyReader(r)
 	defer proxyReader.Close()
 
 	// copy from proxyReader, ignoring errors
-	_, _ = io.Copy(ioutil.Discard, proxyReader)
+	_, _ = io.Copy(io.Discard, proxyReader)
 
 	p.Wait()
 }
