@@ -3,12 +3,13 @@ package main
 import (
 	"flag"
 	"fmt"
+	"io"
 	"math/rand"
 	"sync"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 var quietMode bool
@@ -23,14 +24,7 @@ func main() {
 	// passed wg will be accounted at p.Wait() call
 	p := mpb.New(
 		mpb.WithWaitGroup(&wg),
-		mpb.ContainerOptional(
-			// setting to nil will:
-			// set output to ioutil.Discard and disable refresh rate cycle, in
-			// order not to consume much CPU. Hovewer a single refresh still will
-			// be triggered on bar complete event, per each bar.
-			mpb.WithOutput(nil),
-			quietMode,
-		),
+		mpb.ContainerOptional(mpb.WithOutput(io.Discard), quietMode),
 	)
 	total, numBars := 100, 3
 	wg.Add(numBars)
@@ -47,8 +41,8 @@ func main() {
 			mpb.AppendDecorators(
 				// replace ETA decorator with "done" message, OnComplete event
 				decor.OnComplete(
-					// ETA decorator with ewma age of 60
-					decor.EwmaETA(decor.ET_STYLE_GO, 60), "done",
+					// ETA decorator with ewma age of 30
+					decor.EwmaETA(decor.ET_STYLE_GO, 30), "done",
 				),
 			),
 		)
@@ -62,9 +56,8 @@ func main() {
 				// EWMA's unit of measure is an iteration's duration
 				start := time.Now()
 				time.Sleep(time.Duration(rng.Intn(10)+1) * max / 10)
-				bar.Increment()
-				// we need to call DecoratorEwmaUpdate to fulfill ewma decorator's contract
-				bar.DecoratorEwmaUpdate(time.Since(start))
+				// we need to call EwmaIncrement to fulfill ewma decorator's contract
+				bar.EwmaIncrement(time.Since(start))
 			}
 		}()
 	}
