@@ -4,8 +4,8 @@ import (
 	"math/rand"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func main() {
@@ -15,7 +15,9 @@ func main() {
 	total := 100
 	name := "Single Bar:"
 	bar := p.New(int64(total),
-		mpb.BarStyle().Tip(`-`, `\`, `|`, `/`),
+		mpb.BarStyle().Tip(`-`, `\`, `|`, `/`).TipMeta(func(s string) string {
+			return "\033[31m" + s + "\033[0m" // red
+		}),
 		mpb.PrependDecorators(decor.Name(name)),
 		mpb.AppendDecorators(decor.Percentage()),
 	)
