@@ -20,13 +20,13 @@ func TestBarCompleted(t *testing.T) {
 	bar := p.AddBar(int64(total))
 
 	if bar.Completed() {
-		t.Fail()
+		t.Error("expected bar not to complete")
 	}
 
 	bar.IncrBy(total)
 
 	if !bar.Completed() {
-		t.Error("bar isn't completed after increment")
+		t.Error("expected bar to complete")
 	}
 
 	p.Wait()
@@ -38,13 +38,13 @@ func TestBarAborted(t *testing.T) {
 	bar := p.AddBar(int64(total))
 
 	if bar.Aborted() {
-		t.Fail()
+		t.Error("expected bar not to be aborted")
 	}
 
 	bar.Abort(false)
 
 	if !bar.Aborted() {
-		t.Error("bar isn't aborted after abort call")
+		t.Error("expected bar to be aborted")
 	}
 
 	p.Wait()
@@ -67,26 +67,51 @@ func TestBarSetTotal(t *testing.T) {
 	p.Wait()
 }
 
+func TestBarEnableTriggerCompleteZeroBar(t *testing.T) {
+	p := mpb.New(mpb.WithWidth(80), mpb.WithOutput(io.Discard))
+	bar := p.AddBar(0) // never complete bar
+
+	if bar.Completed() {
+		t.Error("expected bar not to complete")
+	}
+
+	// Calling bar.SetTotal(0, true) has same effect
+	// but this one is more concise and intuitive
+	bar.EnableTriggerComplete()
+
+	if !bar.Completed() {
+		t.Error("expected bar to complete")
+	}
+
+	p.Wait()
+}
+
 func TestBarEnableTriggerCompleteAndIncrementBefore(t *testing.T) {
 	p := mpb.New(mpb.WithWidth(80), mpb.WithOutput(io.Discard))
 	bar := p.AddBar(0) // never complete bar
 
+	targetTotal := int64(80)
+
 	for _, f := range []func(){
 		func() { bar.SetTotal(40, false) },
 		func() { bar.IncrBy(60) },
-		func() { bar.SetTotal(80, false) },
+		func() { bar.SetTotal(targetTotal, false) },
 		func() { bar.IncrBy(20) },
 	} {
 		f()
 		if bar.Completed() {
-			t.Fail()
+			t.Error("expected bar not to complete")
 		}
 	}
 
 	bar.EnableTriggerComplete()
 
 	if !bar.Completed() {
-		t.Fail()
+		t.Error("expected bar to complete")
+	}
+
+	if current := bar.Current(); current != targetTotal {
+		t.Errorf("Expected current: %d, got: %d", targetTotal, current)
 	}
 
 	p.Wait()
@@ -96,22 +121,29 @@ func TestBarEnableTriggerCompleteAndIncrementAfter(t *testing.T) {
 	p := mpb.New(mpb.WithWidth(80), mpb.WithOutput(io.Discard))
 	bar := p.AddBar(0) // never complete bar
 
+	targetTotal := int64(80)
+
 	for _, f := range []func(){
 		func() { bar.SetTotal(40, false) },
 		func() { bar.IncrBy(60) },
-		func() { bar.SetTotal(80, false) },
-		func() { bar.EnableTriggerComplete() },
+		func() { bar.SetTotal(targetTotal, false) },
+		func() { bar.EnableTriggerComplete() }, // disables any next SetTotal
+		func() { bar.SetTotal(100, true) },     // nop
 	} {
 		f()
 		if bar.Completed() {
-			t.Fail()
+			t.Error("expected bar not to complete")
 		}
 	}
 
 	bar.IncrBy(20)
 
 	if !bar.Completed() {
-		t.Fail()
+		t.Error("expected bar to complete")
+	}
+
+	if current := bar.Current(); current != targetTotal {
+		t.Errorf("Expected current: %d, got: %d", targetTotal, current)
 	}
 
 	p.Wait()
