@@ -1,6 +1,6 @@
 package decor
 
-var defaultSpinnerStyle = []string{"⠋", "⠙", "⠹", "⠸", "⠼", "⠴", "⠦", "⠧", "⠇", "⠏"}
+var defaultSpinnerStyle = [...]string{"⠋", "⠙", "⠹", "⠸", "⠼", "⠴", "⠦", "⠧", "⠇", "⠏"}
 
 // Spinner returns spinner decorator.
 //
@@ -9,10 +9,10 @@ var defaultSpinnerStyle = []string{"⠋", "⠙", "⠹", "⠸", "⠼", "⠴", "
 //	`wcc` optional WC config
 func Spinner(frames []string, wcc ...WC) Decorator {
 	if len(frames) == 0 {
-		frames = defaultSpinnerStyle
+		frames = defaultSpinnerStyle[:]
 	}
 	var count uint
-	f := func(s *Statistics) string {
+	f := func(s Statistics) string {
 		frame := frames[count%uint(len(frames))]
 		count++
 		return frame
