@@ -621,6 +621,13 @@ func TestDrawDefault(t *testing.T) {
 				current: 1,
 				want:    " [>-----------------------------------------------------------------------------------------------] ",
 			},
+			{
+				style:   BarStyle().Tip(""),
+				name:    "t,c{100,1}empty_tip",
+				total:   100,
+				current: 1,
+				want:    " [=-----------------------------------------------------------------------------------------------] ",
+			},
 			{
 				style:   BarStyle(),
 				name:    "t,c{100,1}trim",
@@ -636,6 +643,13 @@ func TestDrawDefault(t *testing.T) {
 				current: 99,
 				want:    " [==============================================================================================>-] ",
 			},
+			{
+				style:   BarStyle().Tip(""),
+				name:    "t,c{100,99}empty_tip",
+				total:   100,
+				current: 99,
+				want:    " [===============================================================================================-] ",
+			},
 			{
 				style:   BarStyle(),
 				name:    "t,c{100,99}trim",
@@ -767,24 +781,21 @@ func TestDrawDefault(t *testing.T) {
 	var tmpBuf bytes.Buffer
 	for tw, cases := range testSuite {
 		for _, tc := range cases {
-			s := newTestState(tc.style.Build())
-			s.reqWidth = tc.barWidth
-			s.total = tc.total
+			ps := pState{reqWidth: tc.barWidth}
+			s := ps.makeBarState(tc.total, tc.style.Build())
 			s.current = tc.current
 			s.trimSpace = tc.trim
 			s.refill = tc.refill
-			s.completed = tc.total > 0 && tc.current >= tc.total
-			tmpBuf.Reset()
-			r, err := s.draw(newStatistics(tw, s))
+			r, err := s.draw(s.newStatistics(tw))
 			if err != nil {
-				t.FailNow()
+				t.Fatalf("tw: %d case %q draw error: %s", tw, tc.name, err.Error())
 			}
+			tmpBuf.Reset()
 			_, err = tmpBuf.ReadFrom(r)
 			if err != nil {
 				t.FailNow()
 			}
 			by := tmpBuf.Bytes()
-
 			got := string(by[:len(by)-1])
 			if !utf8.ValidString(got) {
 				t.Fail()
@@ -1222,18 +1233,16 @@ func TestDrawTipOnComplete(t *testing.T) {
 	var tmpBuf bytes.Buffer
 	for tw, cases := range testSuite {
 		for _, tc := range cases {
-			s := newTestState(tc.style.Build())
-			s.reqWidth = tc.barWidth
-			s.total = tc.total
+			ps := pState{reqWidth: tc.barWidth}
+			s := ps.makeBarState(tc.total, tc.style.Build())
 			s.current = tc.current
 			s.trimSpace = tc.trim
 			s.refill = tc.refill
-			s.completed = tc.total > 0 && tc.current >= tc.total
-			tmpBuf.Reset()
-			r, err := s.draw(newStatistics(tw, s))
+			r, err := s.draw(s.newStatistics(tw))
 			if err != nil {
-				t.FailNow()
+				t.Fatalf("tw: %d case %q draw error: %s", tw, tc.name, err.Error())
 			}
+			tmpBuf.Reset()
 			_, err = tmpBuf.ReadFrom(r)
 			if err != nil {
 				t.FailNow()
@@ -1399,18 +1408,16 @@ func TestDrawDoubleWidth(t *testing.T) {
 	var tmpBuf bytes.Buffer
 	for tw, cases := range testSuite {
 		for _, tc := range cases {
-			s := newTestState(tc.style.Build())
-			s.reqWidth = tc.barWidth
-			s.total = tc.total
+			ps := pState{reqWidth: tc.barWidth}
+			s := ps.makeBarState(tc.total, tc.style.Build())
 			s.current = tc.current
 			s.trimSpace = tc.trim
 			s.refill = tc.refill
-			s.completed = tc.total > 0 && tc.current >= tc.total
-			tmpBuf.Reset()
-			r, err := s.draw(newStatistics(tw, s))
+			r, err := s.draw(s.newStatistics(tw))
 			if err != nil {
-				t.FailNow()
+				t.Fatalf("tw: %d case %q draw error: %s", tw, tc.name, err.Error())
 			}
+			tmpBuf.Reset()
 			_, err = tmpBuf.ReadFrom(r)
 			if err != nil {
 				t.FailNow()
@@ -1427,13 +1434,3 @@ func TestDrawDoubleWidth(t *testing.T) {
 		}
 	}
 }
-
-func newTestState(filler BarFiller) *bState {
-	bs := &bState{
-		filler: filler,
-	}
-	for i := 0; i < len(bs.buffers); i++ {
-		bs.buffers[i] = bytes.NewBuffer(make([]byte, 0, 512))
-	}
-	return bs
-}
